use strict;
use warnings;

# ABSTRACT: A Sample module to play with DZ.
package Sample::Module;
{
  $Sample::Module::VERSION = '0.1.0';
}
use English qw( -no_match_vars);
use Carp;

1;

__END__
=pod

=head1 NAME

Sample::Module - A Sample module to play with DZ.

=head1 VERSION

version 0.1.0

=head1 AUTHOR

Abhishek <abhishekisnot@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2012 by Abhishek.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

